@@ -100,7 +100,13 @@ _RAW_OPTION_LEVELS = {
         "REPORT_NETWORK_ALWAYS",
         "L10N_LOCALE",
         "L10N_STRICT",
-        "BROWSER_NETWORK_RECORDER_ENABLED"
+        "BROWSER_NETWORK_RECORDER_ENABLED",
+        "EMAILAUTO_IMAP_HOST",
+        "EMAILAUTO_IMAP_PORT",
+        "EMAILAUTO_IMAP_USESSL",
+        "EMAILAUTO_USER",
+        "EMAILAUTO_PASSWORD",
+        "EMAILAUTO_MAX_WAIT",
     },
 
     ConfigStage.CODED: {
