@@ -1,5 +1,5 @@
 # This file is a part of Arjuna
-# Copyright 2015-2020 Rahul Verma
+# Copyright 2015-2021 Rahul Verma
 
 # Website: www.RahulVerma.net
 
@@ -41,7 +41,6 @@ class TestSessionController:
         self.__configurator = None
         self.__project_config_loaded = False
         self.__guimgr = None
-        self.__session = None
 
     @property
     def id(self):
@@ -77,30 +76,6 @@ class TestSessionController:
             ref_conf_name = "ref"
         return Arjuna.get_config(ref_conf_name)
 
-    def load_tests(self, *, dry_run=False, ref_conf_name=None, rules=None):
-        from arjuna import Arjuna
-        from arjuna.engine.session import MagicTestSession, YamlTestSession
-        
-        session_name = Arjuna.get_config().value(ArjunaOption.RUN_SESSION_NAME).lower()
-        if session_name == "msession":
-            ref_config = self.__msession_config(ref_conf_name)
-            self.__session = MagicTestSession(ref_config, dry_run=dry_run, rules=rules)
-        else:
-            self.__session = YamlTestSession(session_name, ref_conf_name, dry_run=dry_run)
-
-    def load_tests_for_stage(self, *, stage_name, dry_run=False, ref_conf_name=None):
-        ref_config = self.__msession_config(ref_conf_name)
-        from arjuna.engine.session import MagicTestSessionForStage
-        self.__session = MagicTestSessionForStage(stage_name, ref_config, dry_run=dry_run)
-
-    def load_tests_for_group(self, *, group_name, dry_run=False, ref_conf_name=None):
-        ref_config = self.__msession_config(ref_conf_name)
-        from arjuna.engine.session import MagicTestSessionForGroup
-        self.__session = MagicTestSessionForGroup(group_name, ref_config, dry_run=dry_run)
-
-    def run(self):
-        self.__session.run()
-
     def _create_config(self, config, name=None):
         config = Configuration(
             self,
