@@ -1,5 +1,5 @@
 # This file is a part of Arjuna
-# Copyright 2015-2020 Rahul Verma
+# Copyright 2015-2021 Rahul Verma
 
 # Website: www.RahulVerma.net
 
@@ -24,3 +24,8 @@ class CommandEnum(Enum):
     RUN_STAGE = auto()
     RUN_GROUP = auto()
     RUN_SELECTED = auto()
+
+class TargetEnum(Enum):
+    PROJECT = auto()
+    GROUP = auto()
+    SELECTED = auto()
\ No newline at end of file
