@@ -23,15 +23,16 @@ from arjuna.tpi.error import HttpUnexpectedStatusCodeError, HttpSendError
 from arjuna.tpi.parser.json import Json
 from arjuna.tpi.parser.html import Html
 from arjuna.tpi.engine.asserter import AsserterMixIn
+from arjuna.tpi.helper.arjtype import CIStringDict
 from requests.exceptions import ConnectionError, TooManyRedirects
 import time
 
-from .message import HttpMessage
+from .packet import HttpPacket
 
 
-class HttpResponse(HttpMessage):
+class HttpResponse(HttpPacket):
     '''
-        Encapsulates HTTP response message. Contains redirected responses as redirection history, if applicable.
+        Encapsulates HTTP response packet. Contains redirected responses as redirection history, if applicable.
 
         Arguments:
             session: `HttpSession` object which created corresponding `HttpRequest` for this response.
@@ -42,6 +43,7 @@ class HttpResponse(HttpMessage):
         super().__init__(response)
         self.__session = session
         self.__resp = response
+        self.__store = CIStringDict()
 
     @property
     def is_redirect(self):
@@ -50,6 +52,13 @@ class HttpResponse(HttpMessage):
         '''
         return self.__resp.is_redirect
 
+    @property
+    def store(self):
+        '''
+        Values extracted from response and stored.
+        '''
+        return self.__store
+
     @property
     def url(self) -> str:
         ''' 
@@ -89,6 +98,20 @@ class HttpResponse(HttpMessage):
             codes = {codes}
         self.asserter.assert_true(self.status_code in codes, f"HTTP status code {self.status_code} is not expected. Expected: {codes}. {msg}")
 
+    def assert_headers(self, headers: dict, *, msg):
+        '''
+            Assert that all headers in provided in the headers dict are matched in response.
+
+            Arguments:
+                headers: HTTP headers dictionary
+
+            Keyword Arguments:
+                msg: Purpose of this assertion
+        '''
+        for k,v in headers.items():
+            self.asserter.assert_true(k in self.headers, f"HTTP response header {k} is not present in response. {msg}")
+            self.asserter.assert_equal(self.headers[k], v, f"HTTP response header {k} value does not match. {msg}")
+
     @property
     def status(self) -> str:
         ''' 
@@ -97,27 +120,33 @@ class HttpResponse(HttpMessage):
         return self.__resp.reason
 
     @property
-    def text(self) -> str:
-        ''' 
-            HTTP Response content as plain text.
+    def text(self):
+        '''
+            HTTP Response content as Text object.
+        '''
+        from arjuna.tpi.parser.text import Text
+        return Text(self.content)
+
+    @property
+    def content(self):
+        '''
+            HTTP Response content as plain unformatted text.
         '''
         return self.__resp.text
 
-    content = text
-
     @property
     def json(self) -> 'JsonDictOrJsonList':
         ''' 
             HTTP Response content as Arjuna's `JsonDict` or `JsonList` object.
         '''
-        return Json.from_str(self.text)
+        return Json.from_str(self.content)
 
     @property
     def html(self) -> 'HtmlNode':
         ''' 
             HTTP Response content as Arjuna's `HtmlNode` object.
         '''
-        return Html.from_str(self.text)
+        return Html.from_str(self.content)
 
     @property
     def redir_history(self) -> tuple:
@@ -185,6 +214,6 @@ class HttpResponse(HttpMessage):
             status_code = self.status_code,
             status_msg = self.status,
             headers = self.headers,
-            content = self.text
+            content = self.content
         )
 
